/****************************************************************************
**
** Copyright (C) 2013 Jolla Ltd.
** Contact: Petri M. Gerdt <petri.gerdt@jollamobile.com>
**
****************************************************************************/

import QtQuick 2.0
import org.nemomobile.lipstick 0.1
import Sailfish.Silica 1.0
import Sailfish.Ambience 1.0
import com.jolla.lipstick 0.1
import org.nemomobile.configuration 1.0
import Sailfish.Accounts 1.0
import "../scripts/desktop.js" as Desktop

ApplicationWindow {
    id: eventFeedWindow
    property int animationDuration: Lipstick.compositor.eventsActive ? 200 : 0

    cover: undefined
    enabled: !Desktop.instance.deviceIsLocked

    TouchBlocker {
        z: -1
        anchors.fill: parent
    }
    Rectangle {
        // background to differentiate Events View context from normal applications
        opacity: Theme.highlightBackgroundOpacity
        color: Theme.highlightBackgroundColor
        parent: _wallpaperItem
        anchors.fill: parent
    }
    initialPage: Component { Page {
        id: page

        property Item _eventsCloseHint

        property bool eventsPeeking: Lipstick.compositor.eventsPeeking
        onEventsPeekingChanged: {
            if (eventsPeeking) {
                if (!Desktop.instance.inLauncher) {
                    eventFeedWindow._wallpaperVerticalOffset = Lipstick.compositor.backgroundVerticalOffset
                }
            }
        }

        property bool homePeeking: Lipstick.compositor.homePeeking
        onHomePeekingChanged: {
            if (homePeeking) {
                backgroundPositionAnimation.start()
            }
        }

        signal updateRequested

        allowedOrientations: Lipstick.compositor.eventsWindowOrientation

        SmoothedAnimation {
            id: backgroundPositionAnimation
            target: eventFeedWindow
            property: "_wallpaperVerticalOffset"
            to: Lipstick.compositor.backgroundVerticalOffset
            duration: 400
        }

        Timer {
            id: initTimer
            interval: 1000
            running: true
            onTriggered: eventViewList.positionViewAtBeginning()
        }

        EventFeedSocialSubviewModel {
            id: eventFeedListModel
            manager: accountManager
            onNeedsConnectionServicesChanged: Lipstick.compositor.eventsViewNeedsConnectivity = needsConnectionServices
        }

        EventFeedAccountManager {
            id: accountManager
        }

        EventsViewList {
            id: eventViewList
        }

        EventsViewCloseInteractionHint {
            id: secondaryEventsViewCloseHint
        }

        ConfigurationValue {
            id: eventsTutorialConfig
            key: "/desktop/lipstick-jolla-home/show_events_gesture"
        }

        Connections {
            target: Lipstick.compositor
            onEventsActiveChanged: {
                if (!eventsTutorialConfig.value) {
                    secondaryEventsViewCloseHint.eventsActive = Lipstick.compositor.eventsActive
                }
                if (Lipstick.compositor.eventsActive) {
                    lipstickSettings.lockscreenVisible = false
                    if (eventsTutorialConfig.value) {
                        if (_eventsCloseHint == null) {
                            var comp = Qt.createComponent(Qt.resolvedUrl("EventsViewCloseHint.qml"))
                            if (comp.status == Component.Ready) {
                                _eventsCloseHint = comp.createObject(page)
                            }
                        }
                        if (_eventsCloseHint != null) {
                            _eventsCloseHint.start()
                        }
                        eventsTutorialConfig.value = undefined
                    }
                } else {
                    if (_eventsCloseHint != null) {
                        _eventsCloseHint.stop()
                        _eventsCloseHint.destroy()
                        _eventsCloseHint = null
                    }
                    eventViewList.positionViewAtBeginning()
                    if (!Qt.inputMethod.visible) {
                        pageStack.pop(page, PageStackAction.Immediate)
                    }
                }
            }
        }

        Connections {
            target: pageStack
            onDepthChanged: Lipstick.compositor.eventsSubviewVisible = pageStack.depth > 1
        }
    } }
}
